Struct arc_reactor::contrib::StaticFileServer [−][src]
A static File Server implemented as a Middleware
Fields
root: &'static str
the root url for all your files. e.g static, assets
request urls that begin with the supplied value for root would be
matched.
public: PathBuf
Path to folder to serve your static files from.
Methods
impl StaticFileServer[src]
impl StaticFileServerpub fn new(root: &'static str, public: PathBuf) -> Self[src]
pub fn new(root: &'static str, public: PathBuf) -> SelfCreates a StaticFileServer with the given root and pathbuf.